@@ -23,8 +23,12 @@ from circlink.link import LINKS_DIRECTORY, CircuitPythonLink
 
 _TableRowEntry: TypeAlias = Tuple[int, str, bool, pathlib.Path, pathlib.Path, bool, int]
 
-__version__ = "1.0.0"
+__version__ = "1.1.0"
 
+# Prevent running on non-POSIX systems that don't have os.fork()
+if os.name != "posix":
+    print("circlink is currently only available for Linux and macOS")
+    sys.exit(1)
 
 app = Typer()
 
@@ -303,6 +307,18 @@ def restart(link_id: str) -> None:
             clear(link[0])
 
 
+@app.command()
+def detect() -> None:
+    """Attempt to detect a CircuitPython board"""
+
+    device = find_device()
+    if device:
+        print("CircuitPython device detected:", device)
+    else:
+        print("No CircuitPython device detected")
+    sys.exit(0)
+
+
 @app.command()
 def about() -> None:
     """Display information about ``circlink``"""
@@ -312,6 +328,14 @@ def about() -> None:
     sys.exit(0)
 
 
+@app.command()
+def version() -> None:
+    """Display the current version of circlink"""
+
+    print(__version__)
+    sys.exit(0)
+
+
 def main() -> None:
     """Main function that runs when ``circlink`` is called as a CLI"""
 
